### 高度な設定

このセクションは、このソフトウェアの上級ユーザー向けです。ここでは以下の情報を見つけることができます：

1. [**高度な設定**](./advanced.md)
<br>
このセクションでは、特定のソース/ターゲット言語の指定、翻訳サービスの切り替えなどを行うことができます。

2. [**言語コード**](./Language-Codes.md)
<br>
ソース言語やターゲット言語の翻訳に使用するコードがわからない場合は、こちらで確認できます。

3. [**翻訳サービスドキュメント**](./Documentation-of-Translation-Services.md)
<br>
使用中の翻訳サービスのドキュメントを確認する必要がある場合は、このページを参照してください。

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>